@echo off
rem -------------------------------------------------------------------------
rem Script to remove tables from the database.To be run after starting MySQL 
rem Use <NetFlowHome>/bin/startDB.bat to start database
rem -------------------------------------------------------------------------

rem -------------------------------------------------------------------------
rem Setting the variables 
rem -------------------------------------------------------------------------

set TABLELIST=tables.list
set TEMPFILE1=temp.list
set TEMPFILE2=temp1.list
set TEMPFILE3=temp2.list
set TEMPFILE4=temp3.list
set LOGFILE=remove.log
set DBNAME="netflow"
set USERNAME="root"
set PASSWORD=""
set MYSQLEXE=..\mysql\bin\mysql
set PORT=--port=13310
set PORTNO="13310"
set SQLFILE=createBaseTables.sql
set METASQLFILE=populateMetaTable.sql	
set MYSQLSTRING=%MYSQLEXE% %PORT% -u %USERNAME% %PASSWORD% %DBNAME% 

rem -------------------------------------------------------------------------
rem check the server status
rem -------------------------------------------------------------------------
set errmsg="Netflow server is running. Shutdown server before dropping data tables"
set JAVA_HOME=..\jre

set NETFLOW_HOME=../server/default/conf/sample-bindings.xml

set UTIL_CLASSPATH=../server/default/lib/NetFlowUtils.jar;

set JAVA=%JAVA_HOME%\bin\java

set ERRORLEVEL=
%JAVA% "-Dcontext=netflow" -cp %UTIL_CLASSPATH% com.adventnet.netflow.dbutils.NFClientUtil %NETFLOW_HOME% 1
set e=%ERRORLEVEL%
if %e% NEQ -2  goto ERRMSG



rem if %ERRORLEVEL% NEQ -2  goto ERRMSG

rem -------------------------------------------------------------------------
rem removing the old log file
rem -------------------------------------------------------------------------
if exist %LOGFILE% del %LOGFILE% 
 
rem -------------------------------------------------------------------------
rem removing the old table list file
rem -------------------------------------------------------------------------
if exist %TABLELIST% del %TABLELIST% 

rem -------------------------------------------------------------------------
rem removing the old temp file
rem -------------------------------------------------------------------------
if exist %TEMPFILE1% del %TEMPFILE1% 
if exist %TEMPFILE2% del %TEMPFILE2% 
if exist %TEMPFILE3% del %TEMPFILE3% 
if exist %TEMPFILE4% del %TEMPFILE4% 

rem -------------------------------------------------------------------------
rem Checking the password. If no password, mysql string is changed .
rem else proceed with select tables.
rem ------------------------------------------------------------------------
if %PASSWORD% == "" goto NULLCHECK
goto SELECTTABLES

rem -------------------------------------------------------------------------
rem Changing the mysql string.
rem ------------------------------------------------------------------------
:NULLCHECK
set MYSQLSTRING=%MYSQLEXE% %PORT% -u %USERNAME% %DBNAME% 
goto SELECTTABLES

rem -------------------------------------------------------------------------
rem Selecting the tables
rem ------------------------------------------------------------------------
:SELECTTABLES
echo select LOOKUP_TABLENAME from MetaTable | %MYSQLSTRING% >> %TEMPFILE1%
echo select LOOKUP_TABLENAME from RawMetaTable | %MYSQLSTRING% >> %TEMPFILE2%
echo select LOOKUP_TABLENAME from NBAR_MetaTable | %MYSQLSTRING% >> %TEMPFILE3%
echo select LOOKUP_TABLENAME from QOS_MetaTable | %MYSQLSTRING% >> %TEMPFILE4%
echo delete from EventRecord | %MYSQLSTRING%
rem to avoid recreating QOS_MetaTable by using createbasetable 
echo delete from QOS_MetaTable | %MYSQLSTRING%
goto REWRITE

rem -------------------------------------------------------------------------
rem Removing the first entry from the temp.list file and creating new file.
rem then proceed to removetables.
rem ------------------------------------------------------------------------
:REWRITE
findstr /V "LOOKUP_TABLENAME" %TEMPFILE1% >> %TABLELIST%
findstr /V "LOOKUP_TABLENAME" %TEMPFILE2% >> %TABLELIST%
findstr /V "LOOKUP_TABLENAME" %TEMPFILE3% >> %TABLELIST%
findstr /V "LOOKUP_TABLENAME" %TEMPFILE4% >> %TABLELIST%
goto REMOVETABLES


rem -------------------------------------------------------------------------
rem Processing the tables list for removing
rem ------------------------------------------------------------------------
:REMOVETABLES
echo ------------------------------------------------------------------------
echo Started removing contents based on list file
echo ------------------------------------------------------------------------
echo %date%-%time% Started removing contents based on list file  >> %LOGFILE% 2>&1
echo ====================================>> %LOGFILE% 2>&1
call :DROPTABLE DstIf1Min
call :DROPTABLE SrcIf1Min
call :DROPTABLE SrcIfPkt1Min
call :DROPTABLE DstIfPkt1Min
for /f %%f in (%TABLELIST%) do call :DROPTABLE %%f
goto COMPLETED

rem -------------------------------------------------------------------------
rem Dropping tables
rem ------------------------------------------------------------------------
:DROPTABLE 
echo set FOREIGN_KEY_CHECKS=0;drop table if exists %1 | %MYSQLSTRING% >> %LOGFILE% 2>&1
set ERRORLEVEL=%errorlevel%
if ERRORLEVEL 1 goto ERROR %1
echo %date%-%time% Dropped %1 >> %LOGFILE% 2>&1
echo Dropped %1
goto STOP

rem -------------------------------------------------------------------------
rem Error Message
rem ------------------------------------------------------------------------
:ERRMSG
echo %errmsg%
goto STOP

rem -------------------------------------------------------------------------
rem Error in dropping the table
rem ------------------------------------------------------------------------	 
:ERROR
echo Unable to drop %1
echo %date%-%time% Unable to drop %1 >> %LOGFILE% 2>&1
goto STOP

rem -------------------------------------------------------------------------
rem Completed dropping individual tables. 
rem Dropping the MetaTable. 
rem ------------------------------------------------------------------------

:COMPLETED
call :DROPTABLE MetaTable
call :DROPTABLE RawMetaTable
call :DROPTABLE NBAR_MetaTable
call :DROPTABLE FileMetaTable

echo recreating base tables
%MYSQLSTRING% < %SQLFILE%
%MYSQLSTRING% < %METASQLFILE%
echo ====================================>> %LOGFILE% 2>&1
echo %date%-%time% Removed contents >> %LOGFILE% 2>&1

rd /s /q ..\data


echo ------------------------------------------------------------------------
echo --------Going to remove billing metatable entries-----------------------
%JAVA% -cp ../server/default/lib/mysql_connector.jar;../server/default/lib/NetFlowUtils.jar; com.adventnet.netflow.dbutils.DropBillingTables %USERNAME% %PASSWORD% %DBNAME% %PORTNO%
echo --------Finished removing billing metatable entries-----------------------


echo ------------------------------------------------------------------------
echo COMPLETED. See %LOGFILE% for more details
echo ------------------------------------------------------------------------



:STOP
